/*This programme is for Donald's Bread e-textile toy.
It has no fixed maximum sensor value, therefore the calibration phase 
requires some user action to record the maximum sensor value.

By Amy Chen 2021
*/

#include "Adafruit_FreeTouch.h"
#include <LiquidCrystal.h>

int i = 0;
int sensorBase1 = 1025;          // Value used in calibration
int sensorMax1 = 0;           // Value used in calibration

int range1 = 0;
int thhover1 = 0;
int thtouch1 = 0;
int thCover1 = 0;
int removed = 0;

//these are the thresholds for each gesture: over 10%, over 49% and over 80% for each respective gesture

float hover = 0.10;
float touch = 0.49;
float Cover = 0.80;

unsigned long previousMillis = 0;        // will store last time LED was updated
const long interval = 60000;           // interval at which to blink (milliseconds)

Adafruit_FreeTouch qt_1 = Adafruit_FreeTouch(A0, OVERSAMPLE_4, RESISTOR_50K, FREQ_MODE_NONE);

// initialize the library by associating any needed LCD interface pin
// with the arduino pin number it is connected to
const int rs = 12, en = 11, d4 = 10, d5 = 9, d6 = 6, d7 = 5;
LiquidCrystal lcd(rs, en, d4, d5, d6, d7);


void setup() {
  // initialize LCD and set up the number of columns and rows:
  Serial.begin(9600);
  qt_1.begin();
  lcd.begin(16, 2);
  // set the cursor to the top left
  lcd.setCursor(0, 0);

//Calibration Phase - Requires user action

  while (millis() < 10000) {
    lcd.setCursor(0, 0);
    lcd.print("Calibrating...");
    lcd.setCursor(0, 1);
    lcd.print("Cover Sensor");
    int MeasurementsToAverage = 50;
    float sensorValue1 = 0;
    for (int i = 0; i < MeasurementsToAverage; ++i)
    {
      sensorValue1 += qt_1.measure();

      delay(1);
    }
    sensorValue1 /= MeasurementsToAverage;

    if (sensorValue1 < sensorBase1) {
      sensorBase1 = sensorValue1;
    }
    if (sensorValue1 > sensorMax1) {
      sensorMax1 = sensorValue1;
    }

  }
  lcd.clear();
  lcd.setCursor(0, 0);
  lcd.print("Maximum ");
  lcd.print(sensorMax1);
  lcd.setCursor(0, 1);
  lcd.print("Baseline ");
  lcd.print(sensorBase1);
  delay(1000);

  range1 = sensorMax1 - sensorBase1;

  int test = range1 * hover;

  thhover1 = sensorBase1 + (range1 * hover);
  thtouch1 = sensorBase1 + (range1 * touch);
  thCover1 = sensorBase1 + (range1 * Cover);
  removed = sensorBase1 - 100;

  Serial.println(sensorBase1);
  Serial.println(sensorMax1);

}

void loop() {

  int MeasurementsToAverage = 50;

  //Sensor 1
  float Average1 = 0;
  for (int i = 0; i < MeasurementsToAverage; ++i)
  {
    Average1 += qt_1.measure();
    delay(1);
  }
  Average1 /= MeasurementsToAverage;


  if (Average1 > thhover1 && Average1 < thtouch1) {
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("Hey! Stop That!");

    lcd.setCursor(0, 1);
    //  lcd.print("doing there?");
    lcd.print("Current: ");
    lcd.print(Average1);
    
    Serial.print("Hey! Stop That!");
    Serial.println(Average1);
  }

  if (Average1 > thtouch1 && Average1 < thCover1) {
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("No touching!");

    lcd.setCursor(0, 1);
    lcd.print("Current: ");
    lcd.print(Average1);
    
    Serial.print("No touching!");
    Serial.println(Average1);
    
  }

  if (Average1 > thCover1) {
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("Don't take it!");

    lcd.setCursor(0, 1);
    lcd.print("Current: ");
    lcd.print(Average1);

        
    Serial.print("Don't take it!");
    Serial.println(Average1);
  }

  if (Average1 < thhover1 && Average1 > removed) {
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("I love bread");

    lcd.setCursor(0, 1);
    //    lcd.print("Oh boy!");
    lcd.print("Current: ");
    lcd.print(Average1);
    
    Serial.print("I love bread");
    Serial.println(Average1);
  }

  if (Average1 < removed) {
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("It's gone!");
    lcd.setCursor(0, 1);
    lcd.print("Current: ");
    lcd.print(Average1);
    
    Serial.print("It's gone!");
    Serial.println(Average1);
  }
  delay(250);
}
